$wnd.rstudio.runAsyncCallback3("function Hrq(a){this.a=a}\nfunction Jrq(a){this.a=a}\nfunction Srq(a){this.a=a}\nfunction uCf(a,b){var c;for(c=0;c<a.s.a.length;c++){if(V6d(a.s,c).wOc==b){sIf(a.u,LBe(c));break}}}\nfunction Erq(a){var b;b=Frq(a,(Brq(),Arq).i8b(),a.b,Byp(a.c.c));b||Frq(a,Arq.e8b(),a.a,zyp(a.c.c))}\nfunction Grq(a,b){this.c=a;this.b=Byp(a.c).sYb();this.a=zyp(a.c).sYb();xi(b,new Hrq(this),dE?dE:(dE=new yB))}\nfunction Crq(a,b,c){var d;d=pkq(a.b.a);zCf(d,u7p(k7j((YNh(),XNh).a)));!!b&&uCf(d,b);FCf(d,c);wof(d,true);new Grq(a,d);(zVh()||!!$wnd.remoteDesktop)&&IVh()}\nfunction Frq(a,b,c,d){if(gO(c)!==gO(d.sYb())&&gO(d._s())!==gO(d.sYb())){I2e(2,(Brq(),Arq).f8b(),Arq.g8b(b,d.sYb(),d._s()),new Jrq(a),true);return true}else{return false}}\nfunction Orq(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=qAq(a.a.b.a));switch(a.c){case 1:Crq(a.a.a,null,true);break;case 2:Crq(a.a.a,a.b[0],pAe(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].nn()}}\nvar oSB='LaTeX typesetting',pSB='Project Option Unchanged',qSB='You changed the global option for ',rSB=', however the current project is still configured to use ',sSB='weaving Rnw files';VNd(2995,1,{},Grq);var hfc=MAe(2995);VNd(2996,1,KHy,Hrq);_.yo=function Irq(a){Erq(this.a)};var ffc=MAe(2996);VNd(2997,1,JNy,Jrq);_.nn=function Krq(){C9e(this.a.c.a.lh)};var gfc=MAe(2997);VNd(638,1,wiz);_.ln=function Rrq(){Orq((new Srq(this)).a)};VNd(3062,1,hKy,Srq);_.nn=function Trq(){Orq(this.a)};var ifc=MAe(3062);VNd(4144,1,j2A);_.e8b=function Pwq(){return oSB};_.f8b=function Qwq(){return pSB};_.g8b=function Rwq(a,b,c){return qSB+a+FJy+b+rSB+c+'.\\\\n\\\\nDo you want to edit the options for the current project as well?'};_.i8b=function Twq(){return sSB};VNd(4145,1,j2A);_.e8b=function _wq(){return oSB};_.f8b=function axq(){return pSB};_.g8b=function bxq(a,b,c){return qSB+a+FJy+b+rSB+c+'.\\n\\nDo you want to edit the options for the current project as well?'};_.i8b=function dxq(){return sSB};VNd(4143,1,j2A);_.e8b=function lxq(){return 'Mise en page LaTeX'};_.f8b=function mxq(){return 'Option du projet inchang\\xE9e'};_.g8b=function nxq(a,b,c){return \"Vous avez chang\\xE9 l'option globale de \"+a+' en '+b+', mais le projet actuel est toujours configur\\xE9 pour utiliser '+c+'.\\n\\nVoulez-vous \\xE9galement modifier les options du projet actuel ?'};_.i8b=function pxq(){return 'Tisse le fichiers Rnw'};auy(hm)(3);\n//# sourceURL=rstudio-3.js\n")
